@@ -87,12 +87,13 @@ class Account(Entity):
 
         return self.get_device(response.get("device"))
 
-    def get_device(self, device_id, params=None, api_call_kwargs={}, **kwargs):
+    def get_device(self, device_id, params=None, raw=False, api_call_kwargs={}, **kwargs):
         """:obj:`Device`: Fetch an device by its device ID (Dxxxxxxxxxxxx).
 
         Args:
             device_id (str): Device ID.
             params (dict): Optional query parameters.
+            raw (bool): Will return the raw JSON if True. False by default.
             api_call_kwargs (dict): Optional keyword arguments for api call.
             **kwargs (dict): Extra attributes for Device object.
         """
@@ -106,7 +107,10 @@ class Account(Entity):
         if not device_data:
             return None
 
-        device = Device(device_data["device"], device_data, api=self.api, **kwargs)
+        if raw:
+            device = device_data
+        else:
+            device = Device(device_data["device"], device_data, api=self.api, **kwargs)
         return device
 
     def get_devices(
@@ -115,6 +119,7 @@ class Account(Entity):
             zones=None,
             include_subzones=None,
             params=None,
+            raw=False,
             api_call_kwargs={},
             **kwargs
             ):
@@ -124,8 +129,10 @@ class Account(Entity):
             device_id (str): Device ID.
             attributes (list): Optional list of device attributes to return.
             attributes (zones): Optional list of zones to filter.
-            include_subzones (zones): Optional list of subzones to filter.
+            include_subzones (bool): Flag to indicate if should include subzone devices in result.
+                This will only work when `zones` are passed.
             params (dict): Optional query parameters.
+            raw (bool): Will return the raw JSON if True. False by default.
             api_call_kwargs (dict): Optional keyword arguments for api call.
             **kwargs (dict): Extra attributes for Device objects.
         """
@@ -142,16 +149,20 @@ class Account(Entity):
         result = self.api.call("GET", "/accounts/{}/devices".format(self._id), params=params, **api_call_kwargs)
         if not isinstance(result, list):
             raise ValueError("API returned incorrect type")
-        return [
-            Device(device_data["device"], device_data, api=self.api, **kwargs)
-            for device_data in result
-        ]
+        if raw:
+            return result
+        else:
+            return [
+                Device(device_data["device"], device_data, api=self.api, **kwargs)
+                for device_data in result
+            ]
 
-    def get_zones(self, params=None, api_call_kwargs={}, **kwargs):
+    def get_zones(self, params=None, raw=False, api_call_kwargs={}, **kwargs):
         """:obj:`list` of :obj:`Zone`: Fetch a list of all zones in the account.
 
         Args:
             params (dict): Optional query parameters.
+            raw (bool): Will return the raw JSON if True. False by default.
             api_call_kwargs (dict): Optional keyword arguments for api call.
             **kwargs (dict): Extra attributes for Zone objects.
         """
@@ -163,18 +174,22 @@ class Account(Entity):
         )
         if not result:
             return []
-        return [
-            Zone(data['id'], data, api=self.api, **kwargs)
-            for data in result
-        ]
+        if raw:
+            return result
+        else:
+            return [
+                Zone(data['id'], data, api=self.api, **kwargs)
+                for data in result
+            ]
 
-    def get_alert(self, alert_id, attributes=None, params=None, api_call_kwargs={}):
+    def get_alert(self, alert_id, attributes=None, raw=False, params=None, api_call_kwargs={}):
         """:obj:`Alert`: Fetch an Alert by its ID
 
         Args:
             alert_id (str): Alert ID.
             attributes (list): Optional list of attributes to request.
             params (dict): Optional query parameters.
+            raw (bool): Will return the raw JSON if True. False by default.
             api_call_kwargs (dict): Optional keyword arguments for api call.
         """
         alert = get_alert(
@@ -183,17 +198,19 @@ class Account(Entity):
             alert_id,
             attributes=attributes,
             params=params,
+            raw=raw,
             account_name=self.name,
             api_call_kwargs=api_call_kwargs,
         )
         return alert
 
-    def get_alerts(self, attributes=None, params=None, api_call_kwargs={}):
+    def get_alerts(self, attributes=None, params=None, raw=False, api_call_kwargs={}):
         """:obj:`list` of :obj:`Alert`: Fetch a list of alerts for the account, according to the used params
 
         Args:
             attributes (list): Optional list of attributes to request.
             params (dict): Optional query parameters.
+            raw (bool): Will return the raw JSON if True. False by default.
             api_call_kwargs (dict): Optional keyword arguments for api call.
         """
         alerts = get_alerts(
@@ -201,18 +218,20 @@ class Account(Entity):
             self._id,
             attributes=attributes,
             params=params,
+            raw=raw,
             account_name=self.name,
             api_call_kwargs=api_call_kwargs,
         )
         return alerts
 
-    def get_zone_alerts(self, zone_id, attributes=None, params=None, api_call_kwargs={}):
+    def get_zone_alerts(self, zone_id, attributes=None, params=None, raw=False, api_call_kwargs={}):
         """:obj:`list` of :obj:`Alert`: Fetch a list of alerts for the zone, according to the used params
 
         Args:
             zone_id (str): Zone ID.
             attributes (list): Optional list of attributes to request.
             params (dict): Optional query parameters.
+            raw (bool): Will return the raw JSON if True. False by default.
             api_call_kwargs (dict): Optional keyword arguments for api call.
         """
         alerts = get_alerts(
@@ -221,18 +240,20 @@ class Account(Entity):
             zone_id=zone_id,
             attributes=attributes,
             params=params,
+            raw=raw,
             account_name=self.name,
             api_call_kwargs=api_call_kwargs,
         )
         return alerts
 
-    def get_device_alerts(self, device_id, attributes=None, params=None, api_call_kwargs={}):
+    def get_device_alerts(self, device_id, attributes=None, params=None, raw=False, api_call_kwargs={}):
         """:obj:`list` of :obj:`Alert`: Fetch a list of alerts for the device, according to the used params
 
         Args:
             device_id (str): Device ID.
             attributes (list): Optional list of attributes to request.
             params (dict): Optional query parameters.
+            raw (bool): Will return the raw JSON if True. False by default.
             api_call_kwargs (dict): Optional keyword arguments for api call.
         """
         alerts = get_alerts(
@@ -241,19 +262,23 @@ class Account(Entity):
             device_id=device_id,
             attributes=attributes,
             params=params,
+            raw=raw,
             account_name=self.name,
             api_call_kwargs=api_call_kwargs,
         )
         return alerts
 
-    def get_setting(self, setting_name, params=None, api_call_kwargs={}):
+    def get_setting(self, setting_name, params=None, raw=True, api_call_kwargs={}):
         """:obj:`Setting`: Finds a setting by its name.
 
         Args:
             setting_name (string): name of the setting. Has to be a root level entry
             params (dict): Optional query parameters.
+            raw (bool): Will return the raw JSON if True. True by default.
             api_call_kwargs (dict): Optional keyword arguments for api call.
         """
+        if not raw:
+            raise NotImplementedError("Not implemented object version of Setting yet")
         return self.api.call(
             "GET",
             "/accounts/{}/settings/{}".format(self._id, setting_name),
@@ -261,13 +286,16 @@ class Account(Entity):
             **api_call_kwargs
         )
 
-    def get_settings(self, params=None, api_call_kwargs={}):
+    def get_settings(self, params=None, raw=True, api_call_kwargs={}):
         """:obj:`dict`: Fetch a all settings in the account.
 
         Args:
             params (dict): Optional query parameters.
+            raw (bool): Will return the raw JSON if True. True by default.
             api_call_kwargs (dict): Optional keyword arguments for api call.
         """
+        if not raw:
+            raise NotImplementedError("Not implemented object version of Setting yet")
         return self.api.call(
             "GET",
             "/accounts/{}/settings".format(self._id),
@@ -416,12 +444,13 @@ class Account(Entity):
             **api_call_kwargs
         )
 
-    def get_token(self, token_id, params=None, api_call_kwargs={}):
+    def get_token(self, token_id, params=None, raw=False, api_call_kwargs={}):
         """:obj:`list` of :obj:`dict`: Fetch a list of tokens.
 
         Args:
             token_id (str): Token ID.
             params (dict): Optional query parameters.
+            raw (bool): Will return the raw JSON if True. False by default.
             api_call_kwargs (dict): Optional keyword arguments for api call.
         """
 
@@ -431,13 +460,17 @@ class Account(Entity):
             params=params,
             **api_call_kwargs
         )
-        return Token(data['token'], data, account_id=self._id, api=self.api, **api_call_kwargs)
+        if raw:
+            return data
+        else:
+            return Token(data['token'], data, account_id=self._id, api=self.api, **api_call_kwargs)
 
-    def get_tokens(self, params=None, api_call_kwargs={}):
+    def get_tokens(self, params=None, raw=False, api_call_kwargs={}):
         """:obj:`list` of :obj:`dict`: Fetch a list of tokens.
 
         Args:
             params (dict): Optional query parameters.
+            raw (bool): Will return the raw JSON if True. False by default.
             api_call_kwargs (dict): Optional keyword arguments for api call.
         """
 
@@ -449,7 +482,10 @@ class Account(Entity):
         )
         if not result:
             return []
-        return [
-            Token(token_data['token'], token_data, account_id=self._id, api=self.api)
-            for token_data in result
-        ]
+        if raw:
+            return result
+        else:
+            return [
+                Token(token_data['token'], token_data, account_id=self._id, api=self.api)
+                for token_data in result
+            ]
